//LabPlot : TitleDialog.h

#ifndef TITLEDIALOG_H
#define TITLEDIALOG_H

#include "Dialog.h"
#include "Worksheet.h"
#include "Label.h"
#include "RichTextWidget.h"

class TitleDialog: public Dialog
{
	Q_OBJECT
public:
	TitleDialog(MainWin *mw, const char *name);
	void updateDialog();
public slots:
	void setLabel(Label *l) { title=l; rtw->setLabel(l); rtw->update(); }
	Label *getLabel() { return rtw->getLabel(); }
	int Apply() { return apply_clicked(); }
private:
	Label *title;
	RichTextWidget *rtw;
private slots:
	void ok_clicked();
	int apply_clicked();
};
#endif //TITLEDIALOG_H
